<div align = "center">

# QEasyWidgets

A simple Qt widget library.
The python version is based on PySide6.

[![PyPI](https://img.shields.io/pypi/v/QEasyWidgets?color=blue&logo=PYPY&logoColor=blue&style=for-the-badge)](https://pypi.org/project/QEasyWidgets/)&nbsp;

[**简体中文**](./docs/README_CN.md) | **English**

![Title](./docs/media/Title.png)

</div>


## Deployment

### pip

```shell
pip install QEasyWidgets -i https://pypi.org/simple/
```


## Cases
Here are some projects based on QEasyWidgets:
- [Easy Voice Toolkit](https://github.com/Spr-Aachen/Easy-Voice-Toolkit)
- [LLM PromptMaster](https://github.com/Spr-Aachen/LLM-PromptMaster)
- [ParkingLot-Management](https://github.com/Spr-Aachen/ParkingLot-Management)


## Reference
- [Microsoft WinUI-Gallery](https://github.com/microsoft/WinUI-Gallery)
- [PyEasyUtils](https://github.com/Spr-Aachen/PyEasyUtils)